'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.twelveHourTime = exports.dateRangeTodayOrLater = exports.tomorrowOrLater = exports.todayOrLater = exports.laterThan = exports.dateRange = exports.date = exports.ethereumAddress = exports.float = exports.integer = exports.url = exports.email = exports.regex = exports.alphanumeric = exports.gt = exports.maxValue = exports.minValue = exports.number = exports.minLength = exports.maxLength = exports.required = undefined;

var _isNan = require('babel-runtime/core-js/number/is-nan');

var _isNan2 = _interopRequireDefault(_isNan);

var _web = require('web3');

var _web2 = _interopRequireDefault(_web);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var web3 = new _web2.default(); /* eslint-disable import/extensions, import/no-unresolved */

// $FlowFixMe
var required = exports.required = function required(value) {
  return value !== null && value !== undefined && value !== '' ? null : 'Required.';
};

var maxLength = exports.maxLength = function maxLength(max) {
  return function (value) {
    return value && value.length > max ? 'Must be ' + max + ' characters or fewer.' : null;
  };
};

var minLength = exports.minLength = function minLength(min) {
  return function (value) {
    return value && value.length < min ? 'Must be ' + min + ' characters or more.' : null;
  };
};

var number = exports.number = function number(value) {
  return value && (0, _isNan2.default)(Number(value)) ? 'Must be a number.' : null;
};

var minValue = exports.minValue = function minValue(min) {
  return function (value) {
    return value && value < min ? 'Must be at least ' + min + '.' : null;
  };
};

var maxValue = exports.maxValue = function maxValue(max) {
  return function (value) {
    return value && value > max ? 'Must be ' + max + ' or less.' : null;
  };
};

var gt = exports.gt = function gt(x) {
  return function (value) {
    return value && value <= x ? 'Must be greater than ' + x + '.' : null;
  };
};

var alphanumeric = exports.alphanumeric = function alphanumeric(value) {
  return value && !/^[a-z0-9]+$/i.test(value) ? 'Only alphanumeric symbols are allowed.' : null;
};

var regex = exports.regex = function regex(expr, value) {
  var message = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'Invalid characters.';
  return value && !expr.test(value) ? message : null;
};

var email = exports.email = function email(value) {
  return value && !/^[A-Z0-9._%+-]+@([A-Z0-9-]+\.)+[A-Z0-9-]+$/i.test(value) ? 'Invalid email address.' : null;
};

var url = exports.url = function url(value) {
  return value && !/^https?:\/\/(www\.)?[-a-zA-Z0-9@:%._+~#=]{2,256}\.[-a-zA-Z0-9@:%._+~#=]{2,256}\b([-a-zA-Z0-9@:%_+.~#?&//=]*)/i.test(value) ? 'Invalid URL (example: http(s)://www.example.com).' : null;
};

var integer = exports.integer = function integer(value) {
  if (!value) {
    return null;
  }
  var v = Number(value);
  return (0, _isNan2.default)(v) || v % 1 !== 0 ? 'Must be a whole number.' : null;
};

var float = exports.float = function float(value) {
  if (!value) {
    return null;
  }
  return !/^[+-]?\d+(\.\d+)?$/.test(value) ? 'Must be a float number.' : null;
};

var ethereumAddress = exports.ethereumAddress = function ethereumAddress(value) {
  return web3.utils.isAddress(value) ? null : 'Must be a valid Ethereum address.';
};

var date = exports.date = function date(value) {
  return value instanceof Date ? null : 'Pick date from the calendar.';
};

var dateRange = exports.dateRange = function dateRange(value) {
  if (!value) {
    return null;
  }
  if (!(value instanceof Array) || value.length !== 2 || !(value[0] instanceof Date) || !(value[1] instanceof Date)) {
    return 'Pick dates from the calendar.';
  }
  return null;
};

var laterThan = exports.laterThan = function laterThan(x, value, label) {
  return value && x && value.getTime() > x.getTime() ? null : 'Must be later than ' + label + '.';
};

var todayOrLater = exports.todayOrLater = function todayOrLater(date) {
  if (!date) {
    return null;
  }

  // eslint-disable-next-line
  date = new Date(date);

  var now = new Date();
  var dayBegin = new Date(now.getFullYear(), now.getMonth(), now.getDate());

  if (dayBegin.getTime() > date.getTime()) {
    return 'Date is in the past.';
  }

  return null;
};

var tomorrowOrLater = exports.tomorrowOrLater = function tomorrowOrLater(date) {
  if (!date) {
    return null;
  }

  // eslint-disable-next-line
  date = new Date(date);

  var now = new Date();
  now.setDate(now.getDate() + 1);
  var dayBegin = new Date(now.getFullYear(), now.getMonth(), now.getDate());

  if (dayBegin.getTime() > date.getTime()) {
    return 'Date is in the past.';
  }

  return null;
};

var dateRangeTodayOrLater = exports.dateRangeTodayOrLater = function dateRangeTodayOrLater(value) {
  return todayOrLater(value[0]) || todayOrLater(value[1]);
};

var twelveHourTime = exports.twelveHourTime = function twelveHourTime(value) {
  if (!value || !value.timeString) {
    return 'Required.';
  }

  var regex = /^([01]?[0-9]):([012345][0-9])$/;
  var match = regex.exec(value.timeString);

  if (match) {
    var hours = parseInt(match[1]);
    if (hours > 0 && hours <= 12) {
      return null;
    }
  }

  return 'Invalid time.';
};